%bcond_with tests

# for extensions installed with pip, unset -s on python shebang
%global py3_shebang_flags %nil

Summary:        Virtualenv-based automation of test activities
Name:           python-tox
Version:        3.24.5
Release:        5%{?dist}
License:        MIT
URL:            https://tox.readthedocs.io/
Source0:        %{pypi_source tox}

BuildRequires:  python3-devel pyproject-rpm-macros
%if %{with tests}
BuildRequires:  /usr/bin/gcc /usr/bin/git /usr/bin/pip
BuildRequires:  /usr/bin/poetry /usr/bin/pytest /usr/bin/python
BuildRequires:  libffi-devel
# use xdist to speed up the %%check, tests only work if the tested tox is installed
BuildRequires:  python3-pytest-xdist tox = %{version}-%{release}
%endif

BuildArch:      noarch

%description 
This package implements a generic virtualenv management and test command line tool you can use for:
 - checking your package installs correctly with different Python versions and interpreters.
 - running your tests in each of the environments, configuring your test tool of choice.
 - acting as a frontend to Continuous Integration servers, greatly reducing boilerplate and 
   merging CI and shell-based testing.


%package -n tox
Summary:        %{summary}
Provides:       python-tox = %{version}-%{release}
Provides:       python3-tox = %{version}-%{release}
Recommends:     python3.10
Recommends:     python3-devel

%description -n tox 
%{description}


%prep
%autosetup -p1 -n tox-%{version}


%generate_buildrequires
%pyproject_buildrequires -r %{?with_tests:-x testing}


%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files tox


%if %{with tests}
%check
%pytest -n auto
%endif


%files -n tox -f %{pyproject_files}
%{_bindir}/tox
%{_bindir}/tox-quickstart


%changelog
* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.24.5-5
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.24.5-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.24.5-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.24.5-2
- Rebuilt for OpenCloudOS Stream 23

* Thu Dec 22 2022 Wang Guodong <gordonwwang@tencent.com> - 3.24.5-1
- package init.
